@@ -9,7 +9,7 @@ use parent 'Data::TableData::Object::Base';
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-11-17'; # DATE
 our $DIST = 'Data-TableData-Object'; # DIST
-our $VERSION = '0.113'; # VERSION
+our $VERSION = '0.114'; # VERSION
 
 sub new {
     my ($class, $data, $spec) = @_;
@@ -222,7 +222,7 @@ sub switch_cols {
 }
 
 sub add_col {
-    my ($self, $name, $idx, $spec) = @_;
+    my ($self, $name, $idx, $spec, $data) = @_;
 
     die "Column '$name' already exists" if defined $self->col_name($name);
     my $col_count = $self->col_count;
@@ -247,8 +247,10 @@ sub add_col {
         $ff->{$name}{pos} = $idx;
     }
 
+    my $i = 0;
     for my $row (@{ $self->{data} }) {
-        splice @$row, $idx, 0, undef;
+        splice @$row, $idx, 0, ($data ? $data->[$i] : undef);
+        $i++;
     }
 }
 
@@ -287,7 +289,7 @@ Data::TableData::Object::aoaos - Manipulate array of arrays-of-scalars via table
 
 =head1 VERSION
 
-This document describes version 0.113 of Data::TableData::Object::aoaos (from Perl distribution Data-TableData-Object), released on 2021-11-17.
+This document describes version 0.114 of Data::TableData::Object::aoaos (from Perl distribution Data-TableData-Object), released on 2021-11-17.
 
 =head1 SYNOPSIS
 
